@@ -76,7 +76,7 @@ SSMseasonal <- function(period, Q, sea.type = c("dummy", "trigonometric"),
       stop("P1inf must be a (m x m) diagonal matrix where m is the number of states. ")
     P1inf <- matrix(P1inf, m, m)
   }
-  diag(P1inf)[diag(P1) > 0 || is.na(diag(P1))] <- 0
+  diag(P1inf)[diag(P1) > 0 | is.na(diag(P1))] <- 0
   if (missing(Q)) {
     k <- 0
     Qm <- R <- NULL
